==> apache-camel-quarkus-3.15.2-src.zip: camel-quarkus-3.15.2/integration-test-groups/azure/azure-storage-blob/src/main/java/org/apache/camel/quarkus/component/azure/storage/blob/it/AzureStorageHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.azure.storage.blob.it;

import java.util.function.BooleanSupplier;

import org.apache.camel.quarkus.test.mock.backend.MockBackendUtils;
import org.eclipse.microprofile.config.ConfigProvider;

public class AzureStorageHelper {

    private static final BooleanSupplier clientSecretAuthEnabled = new ClientSecretAuthEnabled();
    private static final BooleanSupplier clientCertificateAuthEnabled = new ClientCertificateAuthEnabled();

    public static class ClientSecretAuthEnabled implements BooleanSupplier {
        @Override
        public boolean getAsBoolean() {
            return !MockBackendUtils.startMockBackend() &&
                    isAzureConfigValuePresent("azure.client.id") &&
                    isAzureConfigValuePresent("azure.tenant.id") &&
                    isAzureConfigValuePresent("azure.client.secret");
        }
    }

    public static class ClientCertificateAuthEnabled implements BooleanSupplier {
        @Override
        public boolean getAsBoolean() {
            return !MockBackendUtils.startMockBackend() &&
                    isAzureConfigValuePresent("azure.client.id") &&
                    isAzureConfigValuePresent("azure.tenant.id") &&
                    isAzureConfigValuePresent("azure.client.certificate.path");
        }
    }

    private AzureStorageHelper() {
        // Utility class
    }

    public static boolean isClientSecretAuthEnabled() {
        return clientSecretAuthEnabled.getAsBoolean();
    }

    public static boolean isClientCertificateAuthEnabled() {
        return clientCertificateAuthEnabled.getAsBoolean();
    }

    private static boolean isAzureConfigValuePresent(String name) {
        return ConfigProvider.getConfig()
                .getOptionalValue(name, String.class)
                .isPresent();
    }
}

==> apache-camel-quarkus-3.29.0-src.zip: camel-quarkus-3.29.0/integration-test-groups/azure/azure-storage-blob/src/main/java/org/apache/camel/quarkus/component/azure/storage/blob/it/AzureStorageHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.azure.storage.blob.it;

import java.util.function.BooleanSupplier;

import org.apache.camel.quarkus.test.mock.backend.MockBackendUtils;
import org.eclipse.microprofile.config.ConfigProvider;

public class AzureStorageHelper {

    private static final BooleanSupplier clientSecretAuthEnabled = new ClientSecretAuthEnabled();
    private static final BooleanSupplier clientCertificateAuthEnabled = new ClientCertificateAuthEnabled();

    public static class ClientSecretAuthEnabled implements BooleanSupplier {
        @Override
        public boolean getAsBoolean() {
            return !MockBackendUtils.startMockBackend() &&
                    !isAzureConfigValueEquals("CAMEL_QUARKUS_DISABLE_IDENTITY_EXCEPT_KEY_VAULT", Boolean.class, true) &&
                    isAzureConfigValuePresent("azure.client.id") &&
                    isAzureConfigValuePresent("azure.tenant.id") &&
                    isAzureConfigValuePresent("azure.client.secret");
        }
    }

    public static class ClientCertificateAuthEnabled implements BooleanSupplier {
        @Override
        public boolean getAsBoolean() {
            return !MockBackendUtils.startMockBackend() &&
                    isAzureConfigValuePresent("azure.client.id") &&
                    isAzureConfigValuePresent("azure.tenant.id") &&
                    isAzureConfigValuePresent("azure.client.certificate.path");
        }
    }

    private AzureStorageHelper() {
        // Utility class
    }

    public static boolean isClientSecretAuthEnabled() {
        return clientSecretAuthEnabled.getAsBoolean();
    }

    public static boolean isClientCertificateAuthEnabled() {
        return clientCertificateAuthEnabled.getAsBoolean();
    }

    private static boolean isAzureConfigValuePresent(String name) {
        return ConfigProvider.getConfig()
                .getOptionalValue(name, String.class)
                .isPresent();
    }

    private static <T> boolean isAzureConfigValueEquals(String name, Class<T> type, T expectedValue) {
        return ConfigProvider.getConfig()
                .getOptionalValue(name, type)
                .isPresent()
                && expectedValue.equals(
                        ConfigProvider.getConfig().getValue(name, type));
    }
}
